@@ -959,6 +959,13 @@ class FCServer:
             str_to_bool(resp.findtext("./share/allowpublicuploadonly", "")),
         )
 
+    def deleteshare(self, share: FCShare) -> None:
+        resp = self._api_call(
+            "/core/deleteshare",
+            {"shareid": share.shareid},
+        )
+        self._raise_exception_from_command(resp)
+
     def getshareforpath(self, path: str, adminproxyuserid: str = "") -> FCShare:
         """
         Share 'path'
